@@ -1,6 +1,6 @@
 /*******************************************************************
 *
-* This file is part of the KDE project "Bovo"
+* Copyright 2007  Aron Boström <c02ab@efd.lth.se>
 *
 * Bovo is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
@@ -64,7 +64,7 @@ void AiAron::setSkill(KgDifficultyLevel::StandardLevel skill) {
 }
 
 void AiAron::slotMove() {
-    emit move(Move(m_player, m_board->move()));
+    Q_EMIT move(Move(m_player, m_board->move()));
 }
 
 } /* namespace ai */
